@@ -38,15 +38,15 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 
 #define MAXFLAGS 17
 
-char * GCRFlagNames[]=
+const char * const GCRFlagNames[]=
     {"blkb", "blkm", "blkp", "cc",  "ce",  "r",  "tc", "te", "u",
      "v2",   "vl",   "vd",   "vm",  "vr",  "vu", "x",  "z",  0};
 
-int GCRFlagValue[]=
+const int GCRFlagValue[]=
     {   3,  1,     2,   256,  1024,     8,  128, 512, 4,
        64, 32, 32768,  2048,  8192, 16384,   16,  4096};
 
-char * GCRFlagDescr[]={
+const char * const GCRFlagDescr[]={
 	"3     Both layers are blocked",
 	"1     Location is blocked with metal",
 	"2     Location is blocked with poly",
@@ -210,7 +210,7 @@ gcrDumpChannel(ch)
     FILE * fp, * fopen();
 
     netNames[0]=(GCRNet *) 0;
-    (void) snprintf(name, sizeof(name), "channel.%p", ch);
+    (void) snprintf(name, sizeof(name), "channel.%p", (void *) ch);
     if((fp = fopen(name, "w")) == NULL)
     {
 	TxError("Can't open file %s to dump channel.\n", name);
