@@ -920,7 +920,7 @@ GrOGLDelete(w)
     HashEntry	*entry;
 
     xw = (Window) w->w_grdata;
-    entry = HashLookOnly(&grOGLWindowTable, (char *)xw);
+    entry = HashLookOnly(&grOGLWindowTable, (const char *)(intptr_t)xw);
     HashSetValue(entry,NULL);
 
     XDestroyWindow(grXdpy, xw);
@@ -1075,7 +1075,7 @@ GrOGLIconUpdate(w,text)
      XClassHint	class;
      char	*brack;
 
-     if (w->w_grdata == (ClientData)NULL) return;
+     if (w->w_grdata == PTR2CD(NULL)) return;
      class.res_name = "magic";
      class.res_class = "magic";
      XSetClassHint( grXdpy, wind, &class);
