@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- *  lispMain.c -- 
+ *  lispMain.c --
  *
  *   This module contains the mini-scheme interpreter interface.
  *
@@ -17,7 +17,7 @@
  *  software outside of the United States of America may require an
  *  export license.
  *
- *  $Id: lispMain.c,v 1.1.1.1 2006/04/10 22:03:13 tim Exp $
+ *  $Header$
  *
  *************************************************************************/
 
@@ -88,7 +88,7 @@ LispEvaluate (argc, argv, inFile)
 
   l = LispFrameLookup (LispNewString ("scm-echo-parser-input"),
 		       LispMainFrame);
-  if (l && LTYPE(l) == S_BOOL && LBOOL(l)) 
+  if (l && LTYPE(l) == S_BOOL && LBOOL(l))
     TxPrintf (" [ %s ]\n", output_buf);
   l = LispParseString (output_buf);
   res = LispFrameLookup (LispNewString ("scm-echo-parser-output"),
@@ -99,7 +99,7 @@ LispEvaluate (argc, argv, inFile)
       LispPrint (stdout, l);
       TxPrintf ("\n\n");
     }
-    SigInterruptOnSigIO = FALSE;
+    if (SigInterruptOnSigIO >= 0) SigInterruptOnSigIO = 0;
     SigInterruptPending = FALSE;
     res = LispEval(l,LispMainFrame);
   }
