@@ -23,8 +23,8 @@
  * rcsid $Header: /usr/cvsroot/magic-8.0/mzrouter/mzInternal.h,v 1.2 2008/06/01 18:37:44 tim Exp $
  */
 
-#ifndef _MZINTERNAL_H
-#define _MZINTERNAL_H
+#ifndef _MAGIC__MZROUTER__MZINTERNAL_H
+#define _MAGIC__MZROUTER__MZINTERNAL_H
 
 /*
  * Structures etc. that are exported by the mzrouter are defined in
@@ -39,15 +39,15 @@
  *  the head of that function.
  */
 
-#ifndef _MAGIC_H
+#ifndef _MAGIC__UTILS__MAGIC_H
 #include "utils/magic.h"
 #endif
 
-#ifndef _MZROUTER_H
+#ifndef _MAGIC__MZROUTER__MZROUTER_H
 #include "mzrouter/mzrouter.h"
 #endif
 
-#ifndef _HEAP_H
+#ifndef _MAGIC__UTILS__HEAP_H
 #include "utils/heap.h"
 #endif
 
@@ -504,4 +504,4 @@ extern void mzWalkUDContact();
 #define RC_WALKLRC	1024
 #define RC_DONE		2048
 
-#endif /* _MZINTERNAL_H */
+#endif /* _MAGIC__MZROUTER__MZINTERNAL_H */
